Tests
=====

.. py:module:: pyslet.qtiv2.tests

..	autoclass:: AssessmentTest
	:members:
	:show-inheritance:


Navigation and Submission
-------------------------

..	autoclass:: NavigationMode
	:show-inheritance:


..	autoclass:: SubmissionMode
	:show-inheritance:


..	autoclass:: TestPart
	:members:
	:show-inheritance:


Test Structure
--------------

..	autoclass:: Selection
	:members:
	:show-inheritance:


..	autoclass:: Ordering
	:members:
	:show-inheritance:


..	autoclass:: SectionPart
	:members:
	:show-inheritance:


..	autoclass:: AssessmentSection
	:members:
	:show-inheritance:


..	autoclass:: AssessmentItemRef
	:members:
	:show-inheritance:



